@@ -1,7 +1,7 @@
 /*
  *   Copyright (C) 2006
  *   Siraj Razick <siraj@kdemail.net>
- *   PhobosK <phobosk@mail.kbfx.org>
+ *   PhobosK <phobosk@mail.kbfx.net>
  *   see Also AUTHORS
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,7 @@ class KbfxPlasmaCanvasItemWrapper:public TQObject
 {
 
 		Q_OBJECT
-  TQ_OBJECT
+  
 	public:
 
 		KbfxPlasmaCanvasItemWrapper ( TQCanvas  * canvas );
